import psutil
from process_monitoring.notify import send_email

# Monitor process by PID
def monitor_process(pid, sender_email, receiver_email, password):
    print("Start Monitoring ...")
    try:
        process = psutil.Process(pid)
    except psutil.NoSuchProcess:
        print("Process with PID", pid, "not found.")
        return

    while True:
        if not process.is_running():
            # Process is no longer running, send email notification
            subject = "Process Monitoring - Process Completed"
            message = f"The process with PID {pid} has completed."
            send_email(subject, message, sender_email, receiver_email, password)
            break



import smtplib
from email.message import EmailMessage

# Function to send email notification
def send_email(subject, message, sender_email, receiver_email, password):
    msg = EmailMessage()
    msg['From'] = sender_email
    msg['To'] = receiver_email
    msg['Subject'] = subject
    msg.set_content(message)

    try:
        # Establish a secure connection with the SMTP server
        server = smtplib.SMTP('smtp.gmail.com', 587)
        server.starttls()
        server.login(sender_email, password)

        # Send the email
        server.send_message(msg)
        print("Email notification sent successfully!")
    except Exception as e:
        print("Failed to send email notification:", str(e))
    finally:
        server.quit()



# Testing 
#def send_email(subject, message, sender_email, receiver_email, password):
#    print(subject)
#    print(message)


# Show PID function for target process
import os

def show_pid(write_to_file=False):
    pid = os.getpid()
    print("Current script PID:", pid)
    if write_to_file:
        # Write the PID to .pid_monitor file
        file_path = os.path.join(os.getcwd(), ".pid_monitor")
        with open(file_path, "w") as file:
            file.write(str(pid))


# Read PID from .pid_monitor
def get_pid():
    file_path = os.path.join(os.getcwd(), ".pid_monitor")
    if os.path.isfile(file_path):
        with open(file_path, "r") as file:
            pid = file.read().strip()
            if pid.isdigit():
                return int(pid)
            else:
                print("Invalid PID found in .pid_monitor file.")
    else:
        print(".pid_monitor file not found.")

# Clean up .pid_monitor file
def cleanup():
    file_path = os.path.join(os.getcwd(), ".pid_monitor")
    if os.path.isfile(file_path):
        os.remove(file_path)
        print(".pid_monitor file removed.")
    else:
        print(".pid_monitor file not found.")


from setuptools import setup, find_packages

# read the contents of your README file
from pathlib import Path
this_directory = Path(__file__).parent
LONG_DESCRIPTION = (this_directory / "README.md").read_text()

setup(
    name='process_monitoring_package',
    version='0.0.3',
    description='A package to monitor a process and send email notifications',
    long_description=LONG_DESCRIPTION, 
    long_description_content_type="text/markdown",
    packages=find_packages(),
    author="Chengran",
    license="MIT",
    install_requires=[
        'psutil',
        'requests',
        'tqdm'
    ],
)